import prometheus_client


class Gauge:
    child: prometheus_client.Gauge

    def __init__(self, c: prometheus_client.Gauge, labels: list[str]) -> None:
        self.child = c.labels(*labels)

    def inc(self) -> None:
        self.child.inc()

    def dec(self) -> None:
        self.child.dec()

    def set(self, value: float) -> None:
        self.child.set(value)



from typing import Any

from punch_api.dag import Out


class InputDatasets(dict[str, object]):
    """InputDatasets is used in the execute method of our AbstractNode
    This class gives access to data streams of each node this node is subscribed to
    """

    def get_first(self) -> Any:
        """Get the 'first' dataset (the order is arbitrary due to the map nature)"""
        return self[list(self.keys())[0]]

    def put(self, key: str, value: Any) -> None:
        self[key] = value


class OutputDatasets(dict[Out, object]):
    __outs: list[Out]

    def __init__(self, outs: list[Out]) -> None:
        super().__init__()
        self.__outs = outs

    def put(self, value: Any) -> None:
        """Publish the provided dataset in all the 'out' node configured.

        :param value: the value to publish
        """
        o: Out
        for o in self.__outs:
            self[o] = value



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# License Agreement
# This code is licensed under the outer restricted Tiss license:
#
#  Copyright [2014]-[2019] Thales Services under the Thales Inner Source Software License
#  (Version 1.0, InnerPublic -OuterRestricted the "License");
#
#  You may not use this file except in compliance with the License.
#
#  The complete license agreement can be requested at contact@punchplatform.com.
#
#  Refer to the License for the specific language governing permissions and limitations
#  under the License.
from dataclasses import dataclass, field
from typing import Any


@dataclass
class Column:
    """
    Column definition
    """

    name: str
    type: str | None = None
    default: Any | None = None


@dataclass
class Out:
    """
    Link Between nodes
    """

    id: str
    table: str = "default"
    columns: list[Column] = field(default_factory=list)

    def __post_init__(self):
        self.columns = [Column(**column) for column in self.columns]

    def __hash__(self):
        return hash((self.id, self.table))


@dataclass
class Node:
    """
    Generic node structure
    """

    id: str
    kind: str
    type: str
    settings: dict[str, Any] = field(default_factory=dict)
    out: list[Out] = field(default_factory=list)
    engine_settings: Any = None
    load_control: Any = None
    exit_conditions: Any = None

    def __post_init__(self):
        self.out: list[Out] = [Out(**out) for out in self.out]
